/*  File: mod-gap.cc
 *  Project: Deductor
 *  Created by Zoltán Nagy on 9/8/13.
 *  Modified by D. Soper on 26 February 2019.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*   Deductor headers  */
#include <deductor.h>
#include <proc-hhcjets.h>

/*   Analyser headers  */
#include "analyzer-gap.h"

auto my_jet_module(const deductor_input&)
{
  /*  Using a previously creating the kernel   */
  deductor<hhc> kernel{qcd::ct14n};

  /*    Hard process     */
  auto hard = [=](const model_ref& mdl) -> hhcjets
  {
    int proton = 2212;
    double Ecm = 13.0_TeV;
    double scalefac_pert = 0.707;
    double scalefac_shw = 1.5;
    auto pTlist = {200.0, 300.0, 325.0, 350.0, 375.0, 400.0, 500.0};
    auto y12list = {3.0, 4.0, 4.25, 4.5, 4.75, 5.0, 6.0};
    return {mdl, Ecm, pTlist, y12list, scalefac_pert, scalefac_shw, proton, proton, false};
  };
  
  /*   Jet cross section pT distribution */
  shower_engine_opts opts;
  
  opts.kT_cutoff = 1.0_GeV;         // Shower stops here. Default = 1.0_GeV.
  opts.virtuality_cutoff = 1.0_GeV; // Shower stops here. Default = 1.0_GeV.
  opts.threshold.enabled = true; // Include threshold factor.
  opts.threshold.order_of_soft_corrections = 0u;

  /*  Color approximation on the [tmH, tmH + tnext] evolution range for t.
   *  Here tmH is the shower time for the hard interaction.
   *  Note that later shower steps can't have better approximations than earlier steps.
   */
  opts.color[30.0_GeV] = {4u,2u,0u};   // {Ntot,NRe,NIm}
  // [lower bound on Lambda]
  // {max color_suppression,NRe,NIm}  Ntot = max(NRe,Nim}
  // evolution_type::typeI is the default.
  // opts.color[1.0_GeV] = {4u,0u,0u};
  // No more evolution.
  
  cout<<opts.sanitize()<<"\n";
  
  /*    starting the calculation with various user functions    */
  kernel(ordering::lambda{}, {"JetCalculations", opts}, hard,
         new UserGap{"Gap-anti-kT-R=0.4", {fj::antikt_algorithm, 0.4}});
   }

/*   Always export your module functions!   */
export_my_module jets_module = {
  {"JetsLHC-13TeV", my_jet_module}
};

